pygeodesy.geodsolve.GeodesicLineSolve

Package pygeodesy :: Module geodsolve :: Class GeodesicLineSolve |
[frames] | no frames]

# Class GeodesicLineSolve

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
    solveBase._SolveCapsBase --+
                               |
            solveBase._SolveBase --+
                                   |
               solveBase._Solve3Base --+
                                       |
               solveBase._SolveGDictBase --+
                                           |
                          _GeodesicSolveBase --+
                                               |
      object --+                               |
               |                               |
    named._Named --+                           |
                   |                           |
    named._NamedBase --+                       |
                       |                       |
        karney._CapsBase --+                   |
                           |                   |
    solveBase._SolveCapsBase --+               |
                               |               |
            solveBase._SolveBase --+           |
                                   |           |
               solveBase._Solve3Base --+       |
                                       |       |
               solveBase._SolveGDictBase --+   |
                                           |   |
               solveBase._SolveGDictLineBase --+
                                               |
                                              GeodesicLineSolve

Wrapper to invoke Karney's GeodSolve as an `Exact` version of Karney's Python class GeodesicLine.

Notes:

- Use property `GeodSolve` or env variable `PYGEODESY_GEODSOLVE` to specify the (fully qualified) path to the `GeodSolve` executable.
- This `geodesic` is intended for testing purposes only, it invokes the `GeodSolve` executable for every method call.

Instance Methods
__init__(self, geodesic, lat1, lon1, azi1, caps=32671, **name) New GeodesicLineSolve instance, allowing points to be found along a geodesic starting at `(lat1, lon1)` with azimuth `azi1`. |
Arc(self) Return the arc length to reference point 3 (`degrees` or `NAN`). |
ArcPosition(self, a12, outmask=1929) Find the position on the line given `a12`. |
Distance(self) Return the distance to reference point 3 (`meter` or `NAN`). |
Intersecant2(self, lat0, lon0, radius, **kwds) Not implemented, throws a `NotImplementedError` always. |
PlumbTo(self, lat0, lon0, **kwds) Not implemented, throws a `NotImplementedError` always. |
Position(self, s12, outmask=1929) Find the position on the line given at distance `s12`. |
SetArc(self, a13) Set reference point 3 in terms relative to the first point. |
SetDistance(self, s13) Set reference point 3 in terms relative to the first point. |
toStr(self, **prec_sep_other) Return this `GeodesicLineSolve` as string. |
Inherited from `solveBase._SolveGDictBase`: `ArcDirect`, `Direct`, `Inverse`, `Inverse1` Inherited from `solveBase._SolveCapsBase`: `invokat`, `invoke`, `linelimit` Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
| a13 Get the arc length to reference point 3 (`degrees`).
| azi1 Get the azimuth at the first point (compass `degrees`).
| azi12 Get the azimuth at the first point (compass `degrees`).
| azi1_sincos2 Get the sine and cosine of the first point's azimuth (2-tuple `(sin, cos)`).
| azi12_sincos2 Get the sine and cosine of the first point's azimuth (2-tuple `(sin, cos)`).
| geodesic Get the geodesic (GeodesicSolve).
| s13 Get the distance to reference point 3 (`meter` or `NAN`).
Inherited from `_GeodesicSolveBase`: `GeodSolve` Inherited from `solveBase._SolveGDictLineBase`: `datum`, `ellipsoid`, `lat1`, `lon1` Inherited from `solveBase._SolveBase`: `reverse2`, `unroll` Inherited from `solveBase._SolveCapsBase`: `Exact`, `a`, `b`, `f`, `flattening`, `invokation`, `prec`, `status`, `verbose`, `version` Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, geodesic, lat1, lon1, azi1, caps=32671, **name) (Constructor) |
New GeodesicLineSolve instance, allowing points to be found along a geodesic starting at `(lat1, lon1)` with azimuth `azi1`. Arguments: `geodesic` - The geodesic to use (GeodesicSolve). `lat1` - Latitude of the first point (`degrees`). `lon1` - Longitude of the first point (`degrees`). `azi1` - Azimuth at the first points (compass `degrees`). `caps` - Bit-or'ed combination of Caps values specifying the capabilities the GeodesicLineSolve instance should possess, `caps=Caps.ALL` always. Include `Caps.LINE_OFF` if updates to the `geodesic` should not be reflected in this GeodesicLineSolve instance. `name` - Optional `name=NN` (`str`). Raises: `GeodesicError` - Invalid path for the `GeodSolve` executable or isn't the `GeodSolve` executable, see property `geodesic.GeodSolve`. `TypeError` - Invalid `geodesic`. Overrides: object.__init__

### Arc (self) |
Return the arc length to reference point 3 (`degrees` or `NAN`). See Also: Method SetArc and property a13.

### ArcPosition (self, a12, outmask=1929) |
Find the position on the line given `a12`. Arguments: `a12` - Spherical arc length from the first point to the second point (`degrees`). Returns: A `GDict` with 12 items `lat1, lon1, azi1, lat2, lon2, azi2, m12, a12, s12, M12, M21, S12`.

### Position (self, s12, outmask=1929) |
Find the position on the line given at distance `s12`. Arguments: `s12` - Distance from the first point to the second (`meter`). Returns: A `GDict` with 12 items `lat1, lon1, azi1, lat2, lon2, azi2, m12, a12, s12, M12, M21, S12`, possibly `a12=NAN`.

### SetArc (self, a13) |
Set reference point 3 in terms relative to the first point. Arguments: `a13` - Spherical arc length from the first to the reference point (`degrees`). Returns: The distance `s13` (`meter`) between the first and the reference point or `NAN`.

### SetDistance (self, s13) |
Set reference point 3 in terms relative to the first point. Arguments: `s13` - Distance from the first to the reference point (`meter`). Returns: The arc length `a13` (`degrees`) between the first and the reference point or `NAN`.

### toStr (self, **prec_sep_other) |
Return this `GeodesicLineSolve` as string. Arguments: `prec_sep` - See toStr. Returns: GeodesicLineSolve items (`str`). Overrides: named._Named.toStr

Property Details

### a13 Get the arc length to reference point 3 (`degrees`). Get method: a13(self) - Get the arc length to reference point 3 (`degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Methods Arc and SetArc.

### azi1 Get the azimuth at the first point (compass `degrees`). Get method: azi1(self) - Get the azimuth at the first point (compass `degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### azi12 Get the azimuth at the first point (compass `degrees`). Get method: azi1(self) - Get the azimuth at the first point (compass `degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### azi1_sincos2 Get the sine and cosine of the first point's azimuth (2-tuple `(sin, cos)`). Get method: azi1_sincos2(self) - Get the sine and cosine of the first point's azimuth (2-tuple `(sin, cos)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### azi12_sincos2 Get the sine and cosine of the first point's azimuth (2-tuple `(sin, cos)`). Get method: azi1_sincos2(self) - Get the sine and cosine of the first point's azimuth (2-tuple `(sin, cos)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### geodesic Get the geodesic (GeodesicSolve). Get method: geodesic(self) - Get the geodesic (GeodesicSolve). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### s13 Get the distance to reference point 3 (`meter` or `NAN`). Get method: s13(self) - Get the distance to reference point 3 (`meter` or `NAN`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Methods Distance and SetDistance.